==> bashunit-0.10.0.tar.gz: bashunit-0.10.0/README.md <==
<p align="center">
    <a href="https://github.com/TypedDevs/bashunit/actions/workflows/tests.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/tests.yml/badge.svg" alt="Tests">
    </a>
    <a href="https://github.com/TypedDevs/bashunit/actions/workflows/static_analysis.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/static_analysis.yml/badge.svg" alt="Static analysis">
    </a>
    <a href="https://github.com/TypedDevs/bashunit/actions/workflows/deploy-docs.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/deploy-docs.yml/badge.svg" alt="Docs deployment">
    </a>
<a href="https://github.com/TypedDevs/bashunit/actions/workflows/linter.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/linter.yml/badge.svg" alt="Editorconfig checker">
    </a>
    <a href="https://github.com/TypedDevs/bashunit/blob/main/LICENSE">
        <img src="https://img.shields.io/badge/License-MIT-green.svg" alt="MIT Software License">
    </a>
</p>
<br>
<p align="center">
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset="docs/public/logo_name_dark.svg">
        <img alt="bashunit" src="docs/public/logo_name.svg" width="400">
    </picture>
</p>

<h1 align="center">A simple testing framework for bash scripts</h1>

<p align="center">
    Test your bash scripts in the fastest and simplest way, discover the most modern bash testing framework.
</p>

## Description

**bashunit** is a comprehensive and lightweight testing framework for Bash, focused on the development experience.
It boasts hundreds of assertions and functionalities like spies, mocks, providers and more, offers concise and clear documentation, and has a very active community.

## Documentation

You can find the complete documentation for **bashunit** online, including installation instructions and the various features it provides, in the [official bashunit documentation](https://bashunit.typeddevs.com).

## Contribute

You are welcome to contribute reporting issues, sharing ideas,
or with your pull requests.

Make sure to read our [contribution guide](.github/CONTRIBUTING.md) where you will find, among other things, how to set up your environment with the various tools we use to develop this framework.

## Contributors

<p align="center">
    <img src="https://contributors.nn.ci/api?repo=TypedDevs/bashunit" alt="Contributors list" />
</p>

==> bashunit-0.11.0.tar.gz: bashunit-0.11.0/README.md <==
<p align="center">
    <a href="https://github.com/TypedDevs/bashunit/actions/workflows/tests.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/tests.yml/badge.svg" alt="Tests">
    </a>
    <a href="https://github.com/TypedDevs/bashunit/actions/workflows/static_analysis.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/static_analysis.yml/badge.svg" alt="Static analysis">
    </a>
    <a href="https://github.com/TypedDevs/bashunit/actions/workflows/deploy-docs.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/deploy-docs.yml/badge.svg" alt="Docs deployment">
    </a>
<a href="https://github.com/TypedDevs/bashunit/actions/workflows/linter.yml">
        <img src="https://github.com/TypedDevs/bashunit/actions/workflows/linter.yml/badge.svg" alt="Editorconfig checker">
    </a>
    <a href="https://github.com/TypedDevs/bashunit/blob/main/LICENSE">
        <img src="https://img.shields.io/badge/License-MIT-green.svg" alt="MIT Software License">
    </a>
</p>
<br>
<p align="center">
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset="docs/public/logo-name-dark.svg">
        <img alt="bashunit" src="docs/public/logo-name.svg" width="400">
    </picture>
</p>

<h1 align="center">A simple testing framework for bash scripts</h1>

<p align="center">
    Test your bash scripts in the fastest and simplest way, discover the most modern bash testing framework.
</p>

## Description

**bashunit** is a comprehensive and lightweight testing framework for Bash, focused on the development experience.
It boasts hundreds of assertions and functionalities like spies, mocks, providers and more, offers concise and clear documentation, and has a very active community.

## Documentation

You can find the complete documentation for **bashunit** online, including installation instructions and the various features it provides, in the [official bashunit documentation](https://bashunit.typeddevs.com).

## Contribute

You are welcome to contribute reporting issues, sharing ideas,
or with your pull requests.

Make sure to read our [contribution guide](.github/CONTRIBUTING.md) where you will find, among other things, how to set up your environment with the various tools we use to develop this framework.

## Contributors

<p align="center">
    <img src="https://contributors.nn.ci/api?repo=TypedDevs/bashunit" alt="Contributors list" />
</p>
